/*
 * Copyright 2010 Red Hat, Inc.
 *
 *  Red Hat licenses this file to you under the Apache License, version
 *  2.0 (the "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 *  implied.  See the License for the specific language governing
 *  permissions and limitations under the License.
 */

package org.fusesource.fabric.camel.facade.mbean;

/**
 *
 */
public interface CamelBrowsableEndpointMBean extends CamelEndpointMBean {

    long queueSize();

    String browseExchange(Integer index);

    String browseMessageBody(Integer index);

    /**
     * @deprecated is removed in future Camel releases
     */
    @Deprecated
    String browseMessageAsXml(Integer index);

    String browseMessageAsXml(Integer index, Boolean includeBody);

    String browseAllMessagesAsXml(Boolean includeBody);

    String browseRangeMessagesAsXml(Integer fromIndex, Integer toIndex, Boolean includeBody);

}